@@ -15,10 +15,7 @@ import cdk_nag._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/pdk-nag",
-    "0.14.18",
-    __name__[0:-6],
-    "pdk-nag@0.14.18.jsii.tgz",
+    "@aws-prototyping-sdk/pdk-nag", "0.19.9", __name__[0:-6], "pdk-nag@0.19.9.jsii.tgz"
 )
 
 __all__ = [
